@@ -32,7 +32,6 @@ def test_ppmd7_encoder2():
 def test_ppmd7_decoder():
     decoder = pyppmd.Ppmd7Decoder(6, 16 << 20)
     result = decoder.decode(encoded, 66)
-    result += decoder.flush(66 - len(result))
     assert result == data
     assert decoder.eof
     assert not decoder.needs_input
@@ -42,8 +41,16 @@ def test_ppmd7_decoder2():
     decoder = pyppmd.Ppmd7Decoder(6, 16 << 20)
     result = decoder.decode(encoded[:33], 33)
     result += decoder.decode(encoded[33:], 28)
-    result += decoder.flush(66 - len(result))
+    assert not decoder.eof
+    while len(result) < 66:
+        if decoder.needs_input:
+            result += decoder.decode(b"\0", 66 - len(result))
+            break
+        else:
+            result += decoder.decode(b"", 66 - len(result))
     assert result == data
+    assert not decoder.needs_input
+    assert decoder.eof
 
 
 # test mem_size less than original file size as well
@@ -70,10 +77,13 @@ def test_ppmd7_encode_decode(tmp_path, mem_size):
             dec = pyppmd.Ppmd7Decoder(6, mem_size)
             while remaining > 0:
                 data = target.read(READ_BLOCKSIZE)
-                if len(data) == 0:
-                    res = dec.flush(remaining)
-                else:
-                    res = dec.decode(data, min(remaining, READ_BLOCKSIZE))
+                res = dec.decode(data, min(remaining, READ_BLOCKSIZE))
+                if len(res) == 0:
+                    if dec.needs_input:
+                        res += dec.decode(b"\0", remaining)
+                    else:
+                        res += dec.decode(b"", remaining)
+                    break
                 remaining -= len(res)
                 m2.update(res)
                 out.write(res)
@@ -145,6 +155,12 @@ def test_ppmd7_decode_chunks():
             while remaining > 0:
                 data = f.read(READ_BLOCKSIZE)
                 out = dec.decode(data, remaining)
+                if len(out) == 0:
+                    if dec.needs_input:
+                        out += dec.decode(b"\0", remaining)
+                    else:
+                        out += dec.decode(b"", remaining)
+                    break
                 remaining -= len(out)
                 result += out
             assert len(result) == chunk_sizes[i]
